@@ -3,7 +3,7 @@ import pytest
 
 from mitmproxy.addons import termlog
 from mitmproxy import log
-from mitmproxy.tools.dump import Options
+from mitmproxy.options import Options
 from mitmproxy.test import taddons
 
 
@@ -16,7 +16,7 @@ class TestTermLog:
     ])
     def test_output(self, outfile, expected_out, expected_err, capfd):
         t = termlog.TermLog(outfile=outfile)
-        with taddons.context(options=Options(verbosity=2)) as tctx:
+        with taddons.context(options=Options(verbosity='info')) as tctx:
             tctx.configure(t)
             t.log(log.LogEntry("one", "info"))
             t.log(log.LogEntry("two", "debug"))
